""" 
 * (C) COPYRIGHT International Business Machines Corp. 2012, 2013. All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
"""

#######################################################
# wsadmin script to configure BI Integration Application Server
#######################################################

########### Start Imports ###########
from install.GetProfilePath import GetProfilePath
from install.WASService import WASService

from util.Boolean import * 
import util.utility as util

import was_objs.import_was as wasScript
execfile(wasScript.__file__)
########### End Imports ###########

########### Start Variable Definitions ###########
wasHome = args['wasHome']
profileName = args['profileName']
serverName = args['serverName']
nodeName = args['nodeName']
cellName = args['cellName']
cognosPath = args["cognosPath"]
cognosPathEnvVar = args["cognosPathEnvVar"]

########### End Variable Definitions ###########

# Make sure the WAS profile exists
profilePath = GetProfilePath(wasHome).getProfilePath(profileName)
if profilePath is None:
	raise Exception('Could not find target profile path for profile [' + profileName + ']') 

try:
	print "Configuring Cognos BI Integration Application Server..."

	########### Create a new server ###########
	svr = server.Server(serverName, nodeName, cellName)
	svr.setPortSet(args['portSet'])
	svr.configure()
	
	########### Transaction Time out 
	serverConfigId = svr.getConfigId()
	tranactionServiceId = AdminConfig.list('TransactionService', serverConfigId)
	AdminConfig.modify(tranactionServiceId, [['totalTranLifetimeTimeout', '300']])
	AdminConfig.modify(tranactionServiceId, [['propogatedOrBMTTranLifetimeTimeout', '0']])

	
	########### Start JVM Configuration ###########
	jvmconfig = jvm.JavaVirtualMachine(svr)
	jvmconfig.setInitialHeapSize(args['javaHeap'])
	jvmconfig.setMaximumHeapSize(args['javaHeap'])
	jvmconfig.setGenericJvmArguments(['-Dclient.encoding.override=UTF-8'])
	jvmconfig.configure()
	########### End JVM Configuration ###########
	
	########### Add Cognos PATH definition ###########
	print ( 'Adding Cognos PATH definition ')
	processDef = AdminConfig.list('JavaProcessDef', serverConfigId) 
	AdminConfig.create('Property', processDef, '[[validationExpression ""] [name "' + cognosPathEnvVar + '"] [description ""] [value ' + cognosPath + '] [required "false"]]')

	########### Start UserRegistry DataSource Configuration ###########
	auth = jaasAuthData.JAASAuthData()
	auth.setAlias(args['urDataSourceName'])
	auth.setDescription("Credentials for UserRegistryDS")
	auth.setUserId(args['urDataSourceUserId'])
	auth.setPassword(args['urDataSourcePassword'])
	auth.setServer(svr)
	auth.configure()

	jdbcP = jdbcProvider.JDBCProvider()
	jdbcP.setName(args['urDataSourceName'])
	jdbcP.setVendor(args['urRdbmsVendor'])
	jdbcP.setClasspath(args['urJdbcDriverLocation'])
	jdbcP.setServer(svr)
	jdbcP.configure()

	ds2 = dataSource.DataSource()
	ds2.setName(args['urDataSourceName'])
	ds2.setCategory(args['urDataSourceName'])
	ds2.setJndiName(args['urDataSourceJndiName'])
	if 'urDataSourceUrl' in args.keys() and args['urRdbmsVendor'] == "Oracle" :
		ds2.setURL(args['urDataSourceUrl'])
	else:
		ds2.setResourceAttribute('databaseName', args['urDatabaseServicename'])
		ds2.setResourceAttribute('driverType', 4, 'java.lang.Integer')
		ds2.setResourceAttribute('serverName', args['urDatabaseIP'])
		ds2.setResourceAttribute('portNumber', args['urDatabasePort'], 'java.lang.Integer')
	ds2.setAuthDataAlias(auth)
	ds2.setServer(svr)
	ds2.setJdbcProvider(jdbcP)
	ds2.configure()

	ds2.setProperty("nonTransactionalDataSource", "true", propType="java.lang.Boolean")

	datasourceConfigId = ds2.getConfigId()
	connectionPoolId = AdminConfig.list('ConnectionPool', datasourceConfigId)
	AdminConfig.modify(connectionPoolId, '[[maxConnections "20"] [minConnections "1"]]')
	if args['urRdbmsVendor'] == "DB2" :
		ds2.setResourceAttribute('currentSchema', args['urDb2Schema'])
		ds2.setResourceAttribute('currentFunctionPath', args['urDb2Schema'])
		ds2.configure()

	########### End UserRegistry DataSource Configuration ###########


	########### Start Application Deployment ###########
	print "Application Deployment Started ..."
	
	#bind the userregistry data source to the application
##	inst = installer.Installer(args['appWarLocation'], args['installerPropertiesLocation'])
##	inst.setServer(svr)

##	inst.setMapResRefToEJB([".*", "", 'ServletGateway.war,WEB-INF/web.xml', 'jdbc/' + ds2.getName(), 'javax.sql.DataSource', ds2.getJndiName(), "", "", "", ])
	
	print "Saving changes..."
	AdminConfig.save()
	print "Changes saved..."
	
	########### End Application Deployment ###########
except Exception, e:
	print "Server configuration failed.  Rolling back changes."
	AdminConfig.reset()
	raise # Re-throw to terminate the script

